@@ -5,7 +5,7 @@ use warnings;
 use vars qw($VERSION);
 $VERSION = '0.01';
 
-use base 'Yote::Obj';
+use parent 'Yote::Obj';
 
 
 1;
